@@ -33,6 +33,7 @@
 #include <Vector.hpp>
 #include <S.hpp>
 
+#include <algorithm>
 #include <stdint.h>
 
 using namespace primecount;
@@ -54,7 +55,7 @@ int64_t S2(int64_t x,
   {
     print("");
     print("=== S2(x, y) ===");
-    print("Algorithm: " SIEVE_COUNT_ALGO_NAME);
+    print("Algorithm: " DEFAULT_SIEVE_COUNT_ALGO_NAME);
     time = get_time();
   }
 
@@ -80,6 +81,7 @@ int64_t S2(int64_t x,
     int64_t low1 = max(low, 1);
 
     sieve.pre_sieve(primes, c, low, high);
+    sieve.init_counter(low, high);
     int64_t b = c + 1;
 
     // For c + 1 <= b <= pi_sqrty
